@@ -17,9 +17,9 @@ class Serialiser:
 
     def to_json(self, fp=None, **kwargs):
         if fp:
-            json.dump(self.to_dict(), fp, **kwargs)
+            json.dump(self.to_dict(), fp, indent=2, **kwargs)
         else:
-            return json.dumps(self.to_dict(), **kwargs)
+            return json.dumps(self.to_dict(), indent=2, **kwargs)
 
     @classmethod
     def from_json(cls, js, **kwargs):
@@ -164,7 +164,7 @@ class Synthase(Serialiser):
             self.header,
             str(self.sequence_length),
             self.architecture,
-            ", ".join(self.classification)
+            "|".join(self.classification)
         ]
         return delimiter.join(fields)
 
@@ -191,7 +191,6 @@ class Domain(Serialiser):
         end (int): End of domain hit in parent sequence
         evalue (float): Domain hit E-value
         bitscore (float): Domain hit bitscore
-        partial (str): Domain hit partiality ('C', 'N' or 'NC')
         accession (str): CDD accession of domain family
         superfamily (str): CDD accession of domain superfamily
     """
@@ -205,7 +204,6 @@ class Domain(Serialiser):
         end=None,
         evalue=None,
         bitscore=None,
-        partial=False,
         accession=None,
         superfamily=None,
     ):
@@ -216,7 +214,6 @@ class Domain(Serialiser):
         self.end = end
         self.evalue = evalue
         self.bitscore = bitscore
-        self.partial = partial
         self.accession = accession
         self.superfamily = superfamily
 
@@ -226,14 +223,14 @@ class Domain(Serialiser):
     # TODO: rework, or move this to e.g. domain1.equals(domain2)
     #       since this messes with object comparison e.g. domain1 in [...]
     def __eq__(self, other):
-        if isinstance(other, type(self)):
-            return (
-                self.type == other.type
-                and self.domain == other.domain
-                and self.start == other.start
-                and self.end == other.end
-            )
-        raise NotImplementedError
+        if not isinstance(other, type(self)):
+            raise TypeError
+        return (
+            self.type == other.type
+            and self.domain == other.domain
+            and self.start == other.start
+            and self.end == other.end
+        )
 
     def __len__(self):
         return self.end - self.start
@@ -266,13 +263,16 @@ class Domain(Serialiser):
             "end": self.end,
             "evalue": self.evalue,
             "bitscore": self.bitscore,
-            "partial": self.partial,
             "accession": self.accession,
             "superfamily": self.superfamily,
         }
+    
+    @classmethod
+    def from_dict(cls, d):
+        return cls(**d)
 
 
-class SynthaseContainer(UserList):
+class SynthaseContainer(UserList, Serialiser):
     """Simple container class for Synthase objects.
 
     The purpose of this class is to facilitate batch actions on Synthase objects, i.e.
@@ -340,15 +340,12 @@ class SynthaseContainer(UserList):
                 return synthase
         raise KeyError(f"No Synthase object with header: '{header}'")
 
-    def to_json(self, handle, **kwargs):
-        """Serialise this container to JSON."""
-        dicts = [synthase.to_dict() for synthase in self]
-        json.dump(dicts, handle, **kwargs)
+    def to_dict(self):
+        return [synthase.to_dict() for synthase in self]
 
     @classmethod
-    def from_json(cls, handle):
-        """Load Synthase objects from JSON."""
-        return cls(Synthase.from_dict(entry) for entry in json.load(handle))
+    def from_dict(cls, d):
+        return cls(Synthase.from_dict(s) for s in d)
 
     def filter(self, classes=None, types=None, families=None):
         filtered = [
